@@ -96,6 +96,6 @@ function(x, g, p.adjust.method = p.adjust.methods, ...){
                         dimnames = list(LNAME, levels(g)[1]))
         ans <- list(method = METHOD, data.name = DNAME, p.value = PVAL,
                     statistic = PSTAT, p.adjust.method = p.adjust.method)
-        class(ans) <- "pairwise.htest"
+        class(ans) <- "PMCMR"
         ans
 }
