@@ -97,7 +97,7 @@ function(x, g, p.adjust.method = p.adjust.methods, ...){
 
         ans <- list(method = METHOD, data.name = DNAME, p.value = PVAL,
                     statistic = PSTAT, p.adjust.method = p.adjust.method)
-        class(ans) <- "pairwise.htest"
+        class(ans) <- "PMCMR"
         ans
 }
 
